@@ -2,7 +2,3 @@
 Provide a dataset for pytorch training
 Can instantiate with a personnal dataset (X,y) or a register one
 """
-
-from typing import List
-
-import torch
